@@ -14,10 +14,13 @@ sub progress_bar {
     my $bar_count = 0;
     my $format = $args{format};
     return sub {
+       # disable autoflush to make \r work properly
+       local $| = 1;
        print $bar->report(  $format, ++$bar_count );
     }
 }
-no Any::Moose;
+
+no Any::Moose 'Role';
 
 1;
 
