@@ -2,7 +2,10 @@ package TestApp::ButterflyNet;
 use Any::Moose;
 extends 'Prophet::Record';
 
-has type => ( default => 'net' );
+has type => (
+    is      => 'bare',
+    default => 'net',
+);
 
 __PACKAGE__->meta->make_immutable;
 no Any::Moose;
